'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _components = require('./components');

var components = _interopRequireWildcard(_components);

var _InputWrap = require('./wrappers/InputWrap');

var _InputArrayWrap = require('./wrappers/InputArrayWrap');

var _InputArrayPanel = require('./components/InputArrayPanel');

var _InputArrayTable = require('./components/InputArrayTable');

var _BSInputWrapper = require('./components/BSInputWrapper');

var _reduxFormAuto = require('redux-form-auto');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

/**
 * Data brick used to create a component for a type.
 *
 * @typedef {object} skinTypeMap
 * @property {Component} component
 * @property {function|object} props
 */
exports.default = {
  form: {
    component: components.Form,
    props: {}
  },
  string: {
    component: _InputWrap.InputWrap,
    props: {
      inputWrapper: _BSInputWrapper.BSInputWrapper,
      inputComponent: 'input'
    }
  },
  password: {
    component: _InputWrap.InputWrap,
    props: {
      inputWrapper: _BSInputWrapper.BSInputWrapper,
      inputComponent: 'input',
      type: 'password'
    }
  },
  number: {
    component: _InputWrap.InputWrap,
    props: {
      inputWrapper: _BSInputWrapper.BSInputWrapper,
      inputComponent: 'input',
      type: 'number',
      parse: function parse(value) {
        return Number(value);
      }
    }
  },
  array: {
    component: _InputArrayWrap.InputArrayWrap,
    props: function props(_props) {
      var _props$config = _props.config,
          config = _props$config === undefined ? {} : _props$config,
          propOverrides = _props.propOverrides,
          type = _props.fieldSchema.type,
          name = _props.name;
      var arrayMode = config.arrayMode;

      var arrayHandler = arrayMode == 'table' ? _InputArrayTable.InputArrayTable : _InputArrayPanel.InputArrayPanel;

      return _extends({}, _props, {
        arrayHandler: arrayHandler,
        children: (0, _reduxFormAuto.renderInputs)({
          schema: type[0],
          config: config,
          propOverrides: propOverrides,
          containerField: name
        })
      });
    }
  },
  schema: {
    component: components.Submodel
  },
  select: {
    component: _InputWrap.InputWrap,
    props: function props(_props2) {
      var options = _props2.fieldSchema.options,
          schemaTypeName = _props2.schemaTypeName,
          name = _props2.name;


      var pOptions = typeof options == 'function' ? options(_props2) : options;

      return _extends({}, _props2, {
        inputWrapper: _BSInputWrapper.BSInputWrapper,
        inputComponent: 'select',
        children: components.mapSelectOptions(schemaTypeName, name, pOptions)
      });
    }
  },
  radios: {
    component: _InputWrap.InputWrap,
    props: function props(_props3) {
      var options = _props3.fieldSchema.options;


      var pOptions = typeof options == 'function' ? options(_props3) : options;

      return _extends({}, _props3, {
        inputWrapper: components.RadiosWrapper,
        inputComponent: components.Radio,
        labelTop: true,
        provideMessages: true,
        children: components.mapRadioOptions(_extends({}, _props3, {
          options: pOptions
        }))
      });
    }
  },
  boolean: {
    component: _InputWrap.InputWrap,
    props: function props(_props4) {
      return _extends({}, _props4, {
        inputWrapper: components.CheckboxWrapper,
        inputComponent: components.Checkbox,
        provideMessages: true,
        labelOverride: ''
      });
    }
  }
};